@@ -7,7 +7,7 @@ function (formula, data)
 	if (is(data, "SpatialPixels") && anyDuplicated(data@grid.index) != 0)
 		gridded(data) = FALSE
 
-    m = model.frame(terms(formula), as(data, "data.frame"))
+    m = model.frame(terms(formula), as(data, "data.frame"), na.action = na.fail)
     Y = model.extract(m, "response")
     if (length(Y) == 0)
         stop("no response variable present in formula")
